Package 'BiocMaintainerApp'

Title: View Bioconductor Package Maintainer Information Interactively
Description: This package allows interactive viewing of package maintainer information. The Bioconductor Package Maintainer Application sends yearly verification emails to accept Bioconductor policies; this application also depicts maintainer status on opting in and if the email is deemed valid.
Authors: Lori Shepherd [aut, cre]
Maintainer: Lori Shepherd <[email protected]>
License: Artistic-2.0
Version: 1.1.0
Built: 2026-05-29 08:36:08 UTC
Source: https://github.com/bioc/BiocMaintainerApp

Help Index


Launch Shiny application for Bioconductor Maintainer Validation App

Description

This shiny app allows exploration of package maintainers and validity of emails.

Usage

BiocMaintainerShiny(...)

Arguments

...

Further arguments to the runApp function

Details

This shiny app allows exploration of package maintainers and validity of emails. The associated Bioconductor validation app sends a yearly reminder of Bioconductor policies that maintainers should opt-in. Th app also reflects the status of accepting policies and whether or not the email was reachable.

Value

Displays shiny app in browser

Author(s)

Lori Shepherd

Examples

if (interactive()) {
    BiocMaintainerShiny()
}

Retrieve Maintainer Information

Description

Retrieves maintainer information from the package maintainer validation app

Usage

get_maintainer_data(
  url = "https://pkgmaintainers.bioconductor.org/download-maintainer-db"
)

Arguments

url

Url to retrieve data from whose data can be parsed with jsonlite::fromJSON

Details

Retrieves maintainer information from the package maintainer validation app

Value

data.frame of maintainer information

Author(s)

Lori Shepherd

Examples

tbl <- get_maintainer_data()

Get Maintainer Information by Maintainer Email

Description

Retrieves maintainer information by maintainer email

Usage

getInfoByEmail(email)

Arguments

email

current Bioconductor package maintainer email

Details

Retrieves maintainer information by maintainer email

Value

data.frame of maintainer information including name, package, email, consent_date, email_status, is_email_valid

Author(s)

Lori Shepherd

Examples

tbl <- getInfoByEmail("[email protected]")

Get Maintainer Information by Maintainer Name

Description

Retrieves maintainer information by maintainer name

Usage

getInfoByName(name)

Arguments

name

current Bioconductor package maintainer name

Details

Retrieves maintainer information by maintainer name

Value

data.frame of maintainer information including name, package, email, consent_date, email_status, is_email_valid

Author(s)

Lori Shepherd

Examples

tbl <- getInfoByName("Lori Shepherd")
  tbl <- getInfoByName("Hervé Pagès")

Get Maintainer Information by Package Name

Description

Retrieves maintainer information by package name

Usage

getInfoByPackage(packageName)

Arguments

packageName

current Bioconductor package

Details

Retrieves maintainer information by package name

Value

data.frame of maintainer information including name, package, email, consent_date, email_status, is_email_valid

Author(s)

Lori Shepherd

Examples

tbl <- getInfoByPackage("BiocFileCache")

Check if Maintainer Email is Valid

Description

Retrieves if maintainer email is valid

Usage

isEmailValid(email)

Arguments

email

current Bioconductor package maintainer email

Details

Retrieves if maintainer email is valid.

Value

list. All lists have attribute 'valid' which is TRUE/FALSE. If valid is FALSE, the list will also contain an attribute 'data' with additional diagnostic columns in the database. This includes: email, name, package, consent_date, email_status, is_email_valid, bounce_type, bounce_subtype, smtp_status, diagnostic_code. If no 'data' attribute is included, the email is not found in the database.

Author(s)

Lori Shepherd

Examples

tbl <- isEmailValid("[email protected]")

List All 'Bad' Emails

Description

Retrieves all 'bad' emails.

Usage

listAllBadEmails()

Details

Retrieves all 'bad' emails. A 'bad' email is either invalid or has not consented within the last year.

Value

character vector that lists all maintainer emails.

Author(s)

Lori Shepherd

Examples

tbl <- listAllBadEmails()

List All Emails on Suppression List

Description

Retrieves all emails on AWS Suppression List

Usage

listEmailsOnSuppressionList()

Details

Retrieves all emails on AWS Suppression List

Value

list. First attribute is 'awssuppression' which is TRUE. Second attribute is 'data' which is a data.frame that includes the email and name.

Author(s)

Lori Shepherd

Examples

tbl <- listEmailsOnSuppressionList()

List All Invalid Emails

Description

Retrieves all invalid emails

Usage

listInvalid()

Details

Retrieves all invalid emails

Value

data.frame of maintainer information for anyone with a currently identified invalid email. This includes: email, name, package, email_status, is_email_valid, bounce_type, bounce_subtype, smtp_status, diagnostic_code. An email is designated invalid if the validation email failed to send either for a bounce or because it is on the AWS suppression list.

Author(s)

Lori Shepherd

Examples

tbl <- listInvalid()

List All Maintainer that Need Consent

Description

Retrieves all maintainers that need to consent to Bioconductor policies.

Usage

listNeedsConsent()

Details

Retrieves all maintainers that need to consent to Bioconductor policies. Bioconductor requires maintainers consent to Bioconductor policies once a year.

Value

character vector that lists all maintainer emails that need consent.

Author(s)

Lori Shepherd

Examples

tbl <- listNeedsConsent()