| Title: | View Bioconductor Package Maintainer Information Interactively |
|---|---|
| Description: | This package allows interactive viewing of package maintainer information. The Bioconductor Package Maintainer Application sends yearly verification emails to accept Bioconductor policies; this application also depicts maintainer status on opting in and if the email is deemed valid. |
| Authors: | Lori Shepherd [aut, cre] |
| Maintainer: | Lori Shepherd <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.1.0 |
| Built: | 2026-05-29 08:36:08 UTC |
| Source: | https://github.com/bioc/BiocMaintainerApp |
This shiny app allows exploration of package maintainers and validity of emails.
BiocMaintainerShiny(...)BiocMaintainerShiny(...)
... |
Further arguments to the |
This shiny app allows exploration of package maintainers and validity of emails. The associated Bioconductor validation app sends a yearly reminder of Bioconductor policies that maintainers should opt-in. Th app also reflects the status of accepting policies and whether or not the email was reachable.
Displays shiny app in browser
Lori Shepherd
if (interactive()) { BiocMaintainerShiny() }if (interactive()) { BiocMaintainerShiny() }
Retrieves maintainer information from the package maintainer validation app
get_maintainer_data( url = "https://pkgmaintainers.bioconductor.org/download-maintainer-db" )get_maintainer_data( url = "https://pkgmaintainers.bioconductor.org/download-maintainer-db" )
url |
Url to retrieve data from whose data can be parsed with jsonlite::fromJSON |
Retrieves maintainer information from the package maintainer validation app
data.frame of maintainer information
Lori Shepherd
tbl <- get_maintainer_data()tbl <- get_maintainer_data()
Retrieves maintainer information by maintainer email
getInfoByEmail(email)getInfoByEmail(email)
email |
current Bioconductor package maintainer email |
Retrieves maintainer information by maintainer email
data.frame of maintainer information including name, package, email, consent_date, email_status, is_email_valid
Lori Shepherd
tbl <- getInfoByEmail("[email protected]")tbl <- getInfoByEmail("[email protected]")
Retrieves maintainer information by maintainer name
getInfoByName(name)getInfoByName(name)
name |
current Bioconductor package maintainer name |
Retrieves maintainer information by maintainer name
data.frame of maintainer information including name, package, email, consent_date, email_status, is_email_valid
Lori Shepherd
tbl <- getInfoByName("Lori Shepherd") tbl <- getInfoByName("Hervé Pagès")tbl <- getInfoByName("Lori Shepherd") tbl <- getInfoByName("Hervé Pagès")
Retrieves maintainer information by package name
getInfoByPackage(packageName)getInfoByPackage(packageName)
packageName |
current Bioconductor package |
Retrieves maintainer information by package name
data.frame of maintainer information including name, package, email, consent_date, email_status, is_email_valid
Lori Shepherd
tbl <- getInfoByPackage("BiocFileCache")tbl <- getInfoByPackage("BiocFileCache")
Retrieves if maintainer email is valid
isEmailValid(email)isEmailValid(email)
email |
current Bioconductor package maintainer email |
Retrieves if maintainer email is valid.
list. All lists have attribute 'valid' which is TRUE/FALSE. If valid is FALSE, the list will also contain an attribute 'data' with additional diagnostic columns in the database. This includes: email, name, package, consent_date, email_status, is_email_valid, bounce_type, bounce_subtype, smtp_status, diagnostic_code. If no 'data' attribute is included, the email is not found in the database.
Lori Shepherd
tbl <- isEmailValid("[email protected]")tbl <- isEmailValid("[email protected]")
Retrieves all 'bad' emails.
listAllBadEmails()listAllBadEmails()
Retrieves all 'bad' emails. A 'bad' email is either invalid or has not consented within the last year.
character vector that lists all maintainer emails.
Lori Shepherd
tbl <- listAllBadEmails()tbl <- listAllBadEmails()
Retrieves all emails on AWS Suppression List
listEmailsOnSuppressionList()listEmailsOnSuppressionList()
Retrieves all emails on AWS Suppression List
list. First attribute is 'awssuppression' which is TRUE. Second attribute is 'data' which is a data.frame that includes the email and name.
Lori Shepherd
tbl <- listEmailsOnSuppressionList()tbl <- listEmailsOnSuppressionList()
Retrieves all invalid emails
listInvalid()listInvalid()
Retrieves all invalid emails
data.frame of maintainer information for anyone with a currently identified invalid email. This includes: email, name, package, email_status, is_email_valid, bounce_type, bounce_subtype, smtp_status, diagnostic_code. An email is designated invalid if the validation email failed to send either for a bounce or because it is on the AWS suppression list.
Lori Shepherd
tbl <- listInvalid()tbl <- listInvalid()
Retrieves all maintainers that need to consent to Bioconductor policies.
listNeedsConsent()listNeedsConsent()
Retrieves all maintainers that need to consent to Bioconductor policies. Bioconductor requires maintainers consent to Bioconductor policies once a year.
character vector that lists all maintainer emails that need consent.
Lori Shepherd
tbl <- listNeedsConsent()tbl <- listNeedsConsent()